<!DOCTYPE html>
<html>
  <head>
    <meta charset="utf-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1" />
    <title>{{ sable_config.module_title }}</title>
    <link rel="stylesheet" href="static/mystyles.css" />
    <script
      src="https://kit.fontawesome.com/4d30d3d1aa.js"
      crossorigin="anonymous"
    ></script>
      <script src="https://unpkg.com/lunr@2.3.9/lunr.js"></script>
  </head>
  <body>
    <div class="container">
      <nav class="level pt-6 mb-5 pb-2 bottom-border">
        <div class="level-left">
          <p class="level-item has-text-centered is-size-3 has-text-weight-medium">
            <a class="link is-info" href="index.html">
              {{ sable_config.module_title }}
            </a>
          </p>
        </div>

        <div class="level-right">
          {% if sable_config.enable_lunr_search  %}
          <form action="search.html">
            <input type="text" name="query" class="input mr-3 navbar-search-query-input" placeholder="Search">
            <input type="submit" class="button is-primary mr-5" value="Search" />
          </form>
          {% endif %}

          <p class="level-item has-text-centered is-size-5">
            <a href="{{ sable_config.repository_url }}" class="link is-info">
              {% if sable_config.repository_type | string == "RepositoryType.GITHUB" %}
              <span class="icon">
                <i class="fa-brands fa-github"></i>
              </span>
              {% elif sable_config.repository_type | string == "RepositoryType.BITBUCKET" %}
              <span class="icon">
                <i class="fa-brands fa-bitbucket"></i>
              </span>
              {% endif %}
              <span>Source</span>
            </a>
          </p>
        </div>
      </nav>
    </div>

    <div class="container mb-6">{% block content %}{% endblock %}</div>

    <footer class="footer">
      <div class="content has-text-centered">
        {% if sable_config.footer_content %}
          <p>{{ sable_config.footer_content | safe }}</p>
        {% endif %}
        <p>Built with <strong><a href="https://github.com/markvincze/sabledocs">sabledocs</a></strong>.</p>
      </div>
    </footer>
  </body>
</html>
